// PrivacyDialog.cpp : implementation file
//

#include "stdafx.h"
#include "PSample.h"
#include "PrivacyDialog.h"


// CPrivacyDialog dialog

IMPLEMENT_DYNCREATE(CPrivacyDialog, CDialog)

CPrivacyDialog::CPrivacyDialog(CWnd* pParent /*=NULL*/)
	: CDialog(CPrivacyDialog::IDD, pParent)
	, m_bOnlineHelp(FALSE)
	, m_bOnlineSearch(FALSE)
	, m_bAutoUpdate(FALSE)
	, ERTWER(0)
{
}

CPrivacyDialog::~CPrivacyDialog()
{
}

void CPrivacyDialog::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	DDX_Check(pDX, IDC_ONLINE_HELP, m_bOnlineHelp);
	DDX_Check(pDX, IDC_ONLINE_SEARCH, m_bOnlineSearch);
	DDX_Check(pDX, IDC_AUTO_UPDATE, m_bAutoUpdate);
}

// ---------------------------------------------------------------------------
// Initialize the dialog with values from the registry.
// ---------------------------------------------------------------------------
BOOL CPrivacyDialog::OnInitDialog()
{
	CDialog::OnInitDialog();

	DWORD	dwSize;
	DWORD	dwType;
	HKEY	hKey;
	long	lRes;

	// See if the policy information is in the registry
	lRes = RegOpenKey(HKEY_CURRENT_USER, POLICY_KEY, &hKey);

	if (ERROR_SUCCESS == lRes)  // Has the admin placed settings in the registry?
    { 
		// Yes, indicate that the admin set the privacy settings
		m_bNotOverriddenByAdmin = FALSE;

		// Disable the dialog fields
		GetDlgItem(IDC_ONLINE_HELP)->EnableWindow(FALSE);
		GetDlgItem(IDC_ONLINE_SEARCH)->EnableWindow(FALSE);
		GetDlgItem(IDC_AUTO_UPDATE)->EnableWindow(FALSE);
	}
	else
	{
		// Indicate that the admin did not set the privacy settings
		m_bNotOverriddenByAdmin = TRUE;

		// Get a handle to the user's preference settings
		lRes = RegOpenKey(HKEY_CURRENT_USER, PREFERENCE_KEY, &hKey);
	}
	// If some settings were found read them into the local variables
	if (ERROR_SUCCESS == lRes)
	{
		lRes = RegQueryValueEx(hKey, ONLINE_HELP, 0, &dwType, 
							  (LPBYTE)&m_bOnlineHelp, &dwSize);
		lRes = RegQueryValueEx(hKey, ONLINE_SEARCH, 0, &dwType, 
						      (LPBYTE)&m_bOnlineSearch, &dwSize);
		lRes = RegQueryValueEx(hKey, AUTO_UPDATE, 0, &dwType, 
							  (LPBYTE)&m_bAutoUpdate, &dwSize);
		RegCloseKey(hKey);      
	}
	UpdateData(FALSE);  // Copy the local variables to the dialog fields
	return TRUE;
} // OnInitDialog

BEGIN_MESSAGE_MAP(CPrivacyDialog, CDialog)
	ON_BN_CLICKED(IDOK, OnButtonOK)
END_MESSAGE_MAP()

// CPrivacyDialog message handlers

// ---------------------------------------------------------------------------
// The OK button was pressed. Update the registry if appropriate.
// ---------------------------------------------------------------------------
void CPrivacyDialog::OnButtonOK()
{
	OnOK();

	// If the admin has not overridden the privacy settings then accept
	// any changes that the user may have made.
	if (m_bNotOverriddenByAdmin)
	{
		HKEY	hKey;
		long	lRes;

		// Retrieve the policy information from the registry
		lRes = RegOpenKey(HKEY_CURRENT_USER, PREFERENCE_KEY, &hKey);

		if (ERROR_SUCCESS == lRes)  // Was the registry key opened?
		{
			// Yes, update the values
			RegSetValueEx(hKey, ONLINE_HELP, 0, REG_DWORD, (LPBYTE)&m_bOnlineHelp,
						  sizeof(DWORD));
			RegSetValueEx(hKey, ONLINE_SEARCH, 0, REG_DWORD, (LPBYTE)&m_bOnlineSearch,
						  sizeof(DWORD));
			RegSetValueEx(hKey, AUTO_UPDATE, 0, REG_DWORD, (LPBYTE)&m_bAutoUpdate,
						  sizeof(DWORD));
			RegCloseKey(hKey);      
		}
	}
} // OnButtonOK

